@@ -1,3 +1,6 @@
+"""
+The module contains class definition of DataSetup
+"""
 import abc
 from pygalgen.generator.common.macros.macros import MacrosFactory
 from lxml.etree import ElementTree
@@ -5,9 +8,13 @@ from pygalgen.generator.pluggability.strategy import ProcessingOrder
 from typing import Any
 
 class DataSetup(abc.ABC):
-    def __init__(self, args: Any,
-                 order: ProcessingOrder = ProcessingOrder.DEFAULT):
-        self.order = order
+    """
+    DataSetup is an abstract class which should be extended by Plugin specific
+    classes.
+    This class defines the macros initialization and the default starting xml
+    tree
+    """
+    def __init__(self, args: Any):
         self.args = args
 
     @abc.abstractmethod
@@ -18,3 +25,5 @@ class DataSetup(abc.ABC):
     @abc.abstractmethod
     def initialize_xml_tree(self, xml_tree: ElementTree) -> ElementTree:
         pass
+
+
